-- File-Revision: 2
-- cooldown stuff

function cooldownTimer_OnUpdate(self, elapsed)
  self.elapsed = self.elapsed + elapsed;
  if self.elapsed > .1 then
    if self.time and self.time > 0 then
      cooldownTimer_SetTime(self);
      self:Show();
    else
      self:Hide();
    end
    self.elapsed = 0;
  end
end

function cooldownTimer_SetTimer(self, start, duration, enable, charges, maxcharges)
  local timer = _G[self:GetName().."Timer"];
   
  timer = timer or cooldownTimer_CreateTimer(self);
  if (start and start > 0 and duration > 1.5 and enable > 0) then
    timer.time = duration + start;
    timer:Show();
    cooldownTimer_SetTime(timer);
  else
    timer:Hide();
  end
end

function cooldownTimer_SetTime(timer)
  local timeleft = timer.time - GetTime();

  if timeleft < 0 then
    timer.time = 0;
    timer.text:SetText("");
  elseif timeleft < 1 then
    timer.text:SetFontObject("CooldownFontSmall");
    timer.text:SetText(("%.1f"):format(timeleft));
  elseif timeleft < 60 then
    timer.text:SetFontObject("CooldownFontLarge");
    timer.text:SetText(("%d"):format(timeleft));
  elseif timeleft < 3600 then
    timeleft = floor(timeleft/60);
    timer.text:SetFontObject("CooldownFontLarge");
    timer.text:SetText(("%dm"):format(timeleft));
  else
    timeleft = floor(timeleft/3600);
    timer.text:SetFontObject("CooldownFontLarge");
    timer.text:SetText(("%dh"):format(timeleft));
  end
end

do 
  hooksecurefunc("CooldownFrame_SetTimer",cooldownTimer_SetTimer);
end

function cooldownTimer_CreateTimer(self)
  local frameName = self:GetName().."Timer";
  
  local frame = CreateFrame("FRAME",frameName,self,"CooldownTimerTemplate");

  frame.text:SetText("");
  frame.text:SetTextColor(1.0,0.1,0.1);
  
  frame.time = 0;
  frame.elapsed = 0;
  
  return frame;
end

function cooldownTimerFrame_OnEvent(self, event, arg1)
  -- so need to check all of the action buttons and set the timers
  
  local i
  if HasVehicleActionBar() or HasOverrideActionBar() then
    -- only check vehicle action buttons
    for i = 1, 6 do
      cooldownTimer_CheckTimer(_G["OverrideActionBarButton"..i]);
    end
  else
      -- check all the other bars
    for i = 1, 12 do
      cooldownTimer_CheckTimer(_G["ActionButton"..i]);
      cooldownTimer_CheckTimer(_G["MultiBarLeftButton"..i]);
      cooldownTimer_CheckTimer(_G["MultiBarBottomLeftButton"..i]);
      cooldownTimer_CheckTimer(_G["MultiBarRightButton"..i]);
      cooldownTimer_CheckTimer(_G["MultiBarBottomRightButton"..i]);
      if KUIBBar2 then
        cooldownTimer_CheckTimer(_G["KUIBBar2Button"..i]);
      end
    end
  end
end 

function cooldownTimer_CheckTimer(frame)

  if frame.action then
    local start, duration, enable, charges, maxcharges = GetActionCooldown(frame.action);
    
    if enable then
      cooldownTimer_SetTimer(frame.cooldown, start, duration, enable, charges, maxcharges)
    end
  end
end